CosmoTool: a small mixed bag library for doing cosmology in C++/python
======================================================================



This is cosmotool. I do not provide documentation right now.

